<?php
use Shopware\Components\CSRFWhitelistAware;
class Shopware_Controllers_Backend_PixelBlogExporter extends Shopware_Controllers_Backend_ExtJs  implements CSRFWhitelistAware {

    /**
     * Regular expression pattern for matching a valid UUID of any variant.
     */
    public const VALID_PATTERN = '^[0-9a-f]{32}$';

	protected $format = null;

    /**
     * Document-Metadata / Properties
     *
     * @var array
     */
    public $_document;

    /**
     * Shopware Template Object (Smarty)
     *
     * @var \Enlight_Template_Manager
     */
    public $_template;

    /**
     * Invoice / Document number
     *
     * @var int
     */
    public $_documentID;

    /**
     * Primary key of the created document row (s_order_documents)
     *
     * @var int
     */
    public $_documentRowID;

    /**
     * Hash of the created document row (s_order_documents.hash), will be used as filename when preview is false
     *
     * @var string
     */
    public $_documentHash;

    /**
     * Invoice ID for reference in shipping documents etc.
     *
     * @var string
     */
    public $_documentBid;

    /**
     * Ref to the translation component
     *
     * @var \Shopware_Components_Translation
     */
    public $translationComponent;

    public function getWhitelistedCSRFActions()
    {
        return [

            'getCSVs'
        ];
    }


    public static function randomHex(): string
    {
        $hex = bin2hex(random_bytes(16));
        $timeHi = self::applyVersion(mb_substr($hex, 12, 4), 4);
        $clockSeqHi = self::applyVariant(hexdec(mb_substr($hex, 16, 2)));

        return sprintf(
            '%08s%04s%04s%02s%02s%012s',
            // time low
            mb_substr($hex, 0, 8),
            // time mid
            mb_substr($hex, 8, 4),
            // time high and version
            str_pad(dechex($timeHi), 4, '0', \STR_PAD_LEFT),
            // clk_seq_hi_res
            str_pad(dechex($clockSeqHi), 2, '0', \STR_PAD_LEFT),
            // clock_seq_low
            mb_substr($hex, 18, 2),
            // node
            mb_substr($hex, 20, 12)
        );
    }

    public static function fromBytesToHex(string $bytes): string
    {

        $uuid = bin2hex($bytes);


        return $uuid;
    }

    public static function fromBytesToHexList(array $bytesList): array
    {
        $converted = [];
        foreach ($bytesList as $key => $bytes) {
            $converted[$key] = self::fromBytesToHex($bytes);
        }

        return $converted;
    }

    public static function fromHexToBytesList(array $uuids): array
    {
        $converted = [];
        foreach ($uuids as $key => $uuid) {
            $converted[$key] = self::fromHexToBytes($uuid);
        }

        return $converted;
    }

    /**
     *
     */
    public static function fromHexToBytes(string $uuid): string
    {

        return @hex2bin($uuid);


    }

    /**
     * Generates a md5 binary, to hash the string and returns a UUID in hex
     */
    public static function fromStringToHex(string $string): string
    {
        return self::fromBytesToHex(md5($string, true));
    }

    public static function isValid(string $id): bool
    {
        if (!preg_match('/' . self::VALID_PATTERN . '/', $id)) {
            return false;
        }

        return true;
    }
    public function getCSVsAction(){

        Shopware()->Plugins()->Controller()->ViewRenderer()->setNoRender();
        Shopware()->Plugins()->Controller()->Json()->setRenderer(false);



        Shopware()->Plugins()->Controller()->ViewRenderer()->setNoRender();
        Shopware()->Plugins()->Controller()->Json()->setRenderer(false);

        $auth = Shopware()->Container()->get('Auth');
        if ($auth->hasIdentity()) {






        $locales = 1;
        $dataSQL = "SELECT *  FROM s_blog ";




        $objectData = Shopware()->Db()->fetchAll($dataSQL );

        $PIXUPLOADDIR = Shopware()->DocPath() . 'media/pixelblog_import_export';

        if (!file_exists($PIXUPLOADDIR)) {
            @mkdir($PIXUPLOADDIR, 0755);

        }

        $fileName = $PIXUPLOADDIR . "/blog-" . date('Y-m-d_H_i_s') . ".csv";
        $fileNameLink = "https://www.sonnenmax.de/media/pixelblog_import_export/blog-" . date('Y-m-d_H_i_s') . ".csv";

        $demiter = ';';

        $head = [
            'id',
           // 'categoryid',
            'active',
            'tagsActive',
            'catsActive',
            'navActive',
            'viewsActive',
            'publishActive',
            'authorCardActive',
            'authorActive',
            'stickyActive',
            'detailTemplates',
            'position',
            'subtitle',
            'description',
            'shortDescription',
            'keywords',
            'seoUrl',
            'metaTitle',
            'metaKeywords',
            'metaDescription'

        ];


        $csvFile = fopen($fileName, 'w');
        fputcsv($csvFile, $head, ';');

        foreach ($objectData as $key => $value) {









            $data = [



                $this->fromStringToHex((string)$objectData[$key]['id']),
                $objectData[$key]['active'],
                '0',
                '0',
                '0',
                '0',
                '0',
                '0',
                '0',
                '0',
                'standard',
                $objectData[$key]['id'],
                $objectData[$key]['title'],
                $objectData[$key]['description'],
                $objectData[$key]['short_description'],
                $objectData[$key]['meta_keywords'],
                '',
                $objectData[$key]['meta_title'],
                $objectData[$key]['meta_description'],


                $objectData[$key]['anrede'],
                $objectData[$key]['vorname'],
                $objectData[$key]['nachname'],
                $objectData[$key]['telefon'],
                $objectData[$key]['email'],
                $objectData[$key]['strasse'],
                $objectData[$key]['hausnummer'],
                $objectData[$key]['plz'],
                $objectData[$key]['ort'],
                $objectData[$key]['land'],
                strip_tags(str_replace('<br>', "\r\n",$objectData[$key]['anfrage'])),
                strip_tags(str_replace('<br>', "\r\n",$objectData[$key]['farben'])),
                $objectData[$key]['datum'],
                $objectData[$key]['gesendet'],
                $objectData[$key]['customerip'],
                strip_tags(str_replace('<br>', "\r\n",$objectData[$key]['sunproducts']))




            ];

            fputcsv($csvFile, $data, ';');



        }

        fclose($csvFile);

        if (file_exists($fileName)) {

            header("Content-type: application/csv");
            header("Content-Disposition: attachment; filename="."blog_export_".date("Y-m-d_H:i").".csv");
            header("Content-length: " . filesize($fileName));
            header("Pragma: no-cache");
            header("Expires: 0");
            readfile($fileName);
            exit;
        }

        echo count($data) . ' Daten exportiert in der Datei ' . $fileNameLink;
        }
    }

}